# -*- coding: utf-8 -*-

# © 2017-2019, ETH Zurich, Institut für Theoretische Physik
# Author: Dominik Gresch <greschd@gmx.ch>
"""
This module contains general helper functions to aid in developing AiiDA calculations and workchains.
"""

__version__ = '0.3.2'

from ._get_outputs_dict import *
from ._check_workchain_step import *
from . import process_inputs

__all__ = (['process_inputs'] + _check_workchain_step.__all__ +
           _get_outputs_dict.__all__)



# -*- coding: utf-8 -*-
"""
Defines a helper function to get the outputs of a process.
"""

from fsc.export import export
from aiida.common.links import LinkType


@export
def get_outputs_dict(process):
    """
    Helper function to get the RETURN and CREATE outputs of a process as a dict.
    """
    return {
        link_triplet.link_label: link_triplet.node
        for link_triplet in process.get_outgoing(link_type=(LinkType.RETURN,
                                                            LinkType.CREATE))
    }
